@@ -11,7 +11,7 @@ if {![package vsatisfies [package provide Tcl] 8.4]} {
     }
 }
 
-# All Tcl 8.4+ interps can [load] Thread 2.7.1
+# All Tcl 8.4+ interps can [load] Thread 2.7.2
 #
 # For interps that are not thread-enabled, we still call [package ifneeded].
 # This is contrary to the usual convention, but is a good idea because we
@@ -23,14 +23,14 @@ if {![package vsatisfies [package provide Tcl] 8.4]} {
 # about a thread-disabled interp, instead of the message
 # "can't find package Thread".
 
-package ifneeded Thread 2.7.1 [list load [file join $dir libthread271.so.0.0]]
+package ifneeded Thread 2.7.2 [list load [file join $dir .. .. libtclthread272.so.0.0] Thread]
 
 # package Ttrace uses some support machinery.
 
 # In Tcl 8.4 interps we use some older interfaces
 if {![package vsatisfies [package provide Tcl] 8.5]} {
-    package ifneeded Ttrace 2.7.1 "
-    [list proc thread_source {dir} {
+    package ifneeded Ttrace 2.7.2 "
+    [list proc tclthread_source {dir} {
 	if {[info exists ::env(TCL_THREAD_LIBRARY)] &&
 		[file readable $::env(TCL_THREAD_LIBRARY)/ttrace.tcl]} {
 	    source $::env(TCL_THREAD_LIBRARY)/ttrace.tcl
@@ -43,14 +43,14 @@ if {![package vsatisfies [package provide Tcl] 8.5]} {
 	    ::ttrace::update
 	}
     }]
-    [list thread_source $dir]
-    [list rename thread_source {}]"
+    [list tclthread_source $dir]
+    [list rename tclthread_source {}]"
     return
 }
 
 # In Tcl 8.5+ interps; use [::apply]
 
-package ifneeded Ttrace 2.7.1 [list ::apply {{dir} {
+package ifneeded Ttrace 2.7.2 [list ::apply {{dir} {
     if {[info exists ::env(TCL_THREAD_LIBRARY)] &&
 	[file readable $::env(TCL_THREAD_LIBRARY)/ttrace.tcl]} {
 	source $::env(TCL_THREAD_LIBRARY)/ttrace.tcl
